<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="et">
<context>
    <name>CryptoDoc</name>
    <message>
        <source>Container is not open</source>
        <translation>Turvaümbrik ei ole avatud</translation>
    </message>
    <message>
        <source>Container is encrypted</source>
        <translation>Turvaümbrik on krüpteeritud</translation>
    </message>
    <message>
        <source>Failed to add file</source>
        <translation>Faili lisamine ebaõnestus</translation>
    </message>
    <message>
        <source>Failed to calculate digest</source>
        <translation>Räsi arvutamine ei õnnestunud</translation>
    </message>
    <message>
        <source>Failed to add key</source>
        <translation>Adressaadi lisamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed decrypt data</source>
        <translation>Andmete dekrüpteerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to read decrypted data</source>
        <translation>Dekrüpteeritud andmete lugemine ebaõnnstus</translation>
    </message>
    <message>
        <source>Failed to encrypt data</source>
        <translation>Andmete krüpteerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to open crypted document</source>
        <translation>Turvaümbriku avamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to remove file</source>
        <translation>Faili eemaldamine ebaõnestus</translation>
    </message>
    <message>
        <source>Failed to remove key</source>
        <translation>Adressaadi eemaldamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Container is not crypted</source>
        <translation>Turvaümbrik pole krüpteeritud</translation>
    </message>
    <message>
        <source>Failed to save encrpyted file</source>
        <translation>Krüpteeritud faili salvestamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to save file</source>
        <translation>Faili salvestamine ebaõnestus</translation>
    </message>
    <message>
        <source>Document not open</source>
        <translation>Turvaümbrik pole avatud</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation>Teegi viga</translation>
    </message>
    <message>
        <source>Key already exists</source>
        <translation>Adressaat on juba lisatud</translation>
    </message>
    <message>
        <source>Failed to create temporary files&lt;br /&gt;%1</source>
        <translation>Ajutiste failde loomine ebaõnnestus&lt;br /&gt;%1</translation>
    </message>
    <message>
        <source>You do not have the key to decrypt this document</source>
        <translation>Sul puudub võti millega dekrüpteerida seda turvaümbrikut</translation>
    </message>
    <message>
        <source>No keys specified</source>
        <translation>Ühtegi adressaati ei ole lisatud</translation>
    </message>
    <message>
        <source>Failed to save file &apos;%1&apos;</source>
        <translation>Faili salvestamine ebaõnnestus &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Failed to encrypt data.&lt;br /&gt;File does not exsist %1</source>
        <translation>Andmete krüpteerimine ebaõnnestus&lt;br /&gt;Valitud faili ei eksisteeri %1</translation>
    </message>
</context>
<context>
    <name>KeyAddDialog</name>
    <message>
        <source>Add Recipient</source>
        <translation>Lisa adressaat</translation>
    </message>
    <message>
        <source>SK Certificates</source>
        <translation>SK sertifikaadihoidla</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Otsi</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Omanik</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Väljaandja</translation>
    </message>
    <message>
        <source>Expiry date</source>
        <translation>Aegumiskuupäev</translation>
    </message>
    <message>
        <source>Social security number is not valid!</source>
        <translation>Isikukood pole korrektne!</translation>
    </message>
    <message>
        <source>Add cert</source>
        <translation>Lisa sertifikaat</translation>
    </message>
    <message>
        <source>Used certificates</source>
        <translation>Kasutatud sertifikaadid</translation>
    </message>
    <message>
        <source>Add cert from card</source>
        <translation>Lisa sertifikaat kaardilt</translation>
    </message>
    <message>
        <source>Certificates (*.pem *.cer *.crt)</source>
        <translation>Sertifikaadid (*.pem *.cer *.crt)</translation>
    </message>
    <message>
        <source>Failed to open certifiacte</source>
        <translation>Sertifikaadi avamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to read certificate</source>
        <translation>Sertifikaadi lugemine ebaõnnestus</translation>
    </message>
    <message>
        <source>Add cert from file</source>
        <translation>Lisa sertifikaat failist</translation>
    </message>
    <message>
        <source>Personal code:</source>
        <translation>Isikukood:</translation>
    </message>
    <message>
        <source>This certificate is not usable for crypting</source>
        <translation>Selle sertifikaadiga ei saa krüpteerida</translation>
    </message>
    <message>
        <source>Company name:</source>
        <translation>Asutus:</translation>
    </message>
    <message>
        <source>Empty result</source>
        <translation>Ei leidnud midagi</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <source>Are you sure that you want use certificate for encrypting, which expired on %1?&lt;br /&gt;When decrypter has updated certificates then decrypting is impossible.</source>
        <translation>Kas oled kindel, et soovid kasutada krüpteerimiseks sertifikaati, mis aegus %1?&lt;br /&gt;Juhul, kui dekrüpteerija on oma sertifikaate uuendanud, ei ole dekrüpteerimine võimalik.</translation>
    </message>
    <message>
        <source>Keys added successfully</source>
        <translation>Adressaat on edukalt lisatud</translation>
    </message>
    <message>
        <source>Failed to add keys</source>
        <translation>Adressaadi lisamine ebaõnnestus</translation>
    </message>
</context>
<context>
    <name>KeyDialog</name>
    <message>
        <source>Crypt method</source>
        <translation>Krüpteerimismeetod</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Aegub</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Väljaandja</translation>
    </message>
    <message>
        <source>Crypt recipient</source>
        <translation>Krüpteerida adressaadile</translation>
    </message>
    <message>
        <source>Attribute</source>
        <translation>Atribuut</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Väärtus</translation>
    </message>
    <message>
        <source>Show certificate</source>
        <translation>Näita sertifikaati</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Adressaat</translation>
    </message>
</context>
<context>
    <name>KeyWidget</name>
    <message>
        <source>Show details</source>
        <translation>Vaata üksikasju</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
</context>
<context>
    <name>LdapSearch</name>
    <message>
        <source>Failed to init ldap</source>
        <translation>LDAP initsialiseerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to init ldap search</source>
        <translation>LDAP otsingu initsialiseerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to get result</source>
        <translation>Ei saanud LDAP päringule vastust</translation>
    </message>
    <message>
        <source>Empty result</source>
        <translation>Ei leidnud midagi</translation>
    </message>
    <message>
        <source>LDAP server is unavailable.</source>
        <translation>Ei saa ühendust LDAP serveriga.</translation>
    </message>
    <message>
        <source>Error Code: %1 (%2)</source>
        <translation>Veakood: %1 (%2)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Abi</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Edasi</translation>
    </message>
    <message>
        <source>Open container</source>
        <translation>Ava turvaümbrik</translation>
    </message>
    <message>
        <source>Select folder where files will be stored</source>
        <translation>Vali kataloog kuhu failid salvestatakse</translation>
    </message>
    <message>
        <source>Container: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Turvaümbrik: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Select documents</source>
        <translation>Lisa failid</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Salvesta fail</translation>
    </message>
    <message>
        <source>Documents (*.cdoc)</source>
        <translation>Turvaümbrikud (*.cdoc)</translation>
    </message>
    <message>
        <source>Decrypt</source>
        <translation>Dekrüpteeri</translation>
    </message>
    <message>
        <source>Encrypt</source>
        <translation>Krüpteeri</translation>
    </message>
    <message>
        <source>I want to:</source>
        <translation>Ma tahan:</translation>
    </message>
    <message>
        <source>Container content:</source>
        <translation>Turvaümbriku sisu:</translation>
    </message>
    <message>
        <source>Keys</source>
        <translation>Adressaadid</translation>
    </message>
    <message>
        <source>Container contains file with same name, ovewrite?</source>
        <translation>Turvaümbrik sisaldab juba sellise nimega faili, kas kirjutada üle?</translation>
    </message>
    <message>
        <source>This container contains signature! Open with QDigiDocClient?</source>
        <translation>See on digitaalallkirjaga fail!
Kas avan Digidoc kliendiga?</translation>
    </message>
    <message>
        <source>No card in reader</source>
        <translation>Kaarti pole lugejas</translation>
    </message>
    <message>
        <source>Loading data</source>
        <translation>Loen andmeid</translation>
    </message>
    <message>
        <source>Error code: %1</source>
        <translation>Veakood: %1</translation>
    </message>
    <message>
        <source>Yes, I will use ID-card certificate only for secure transfer</source>
        <translation>Jah, ma kasutan ID-kaardi krüpteerimisfunktsiooni vaid andmete turvaliseks edastamiseks</translation>
    </message>
    <message>
        <source>Container:</source>
        <translation>Turvaümbrik:</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;email&quot;&gt;Send container to email&lt;/a&gt;&lt;br /&gt;
&lt;a href=&quot;browse&quot;&gt;Browse container location&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;email&quot;&gt;Saada turvaümbrik e-postiga&lt;/a&gt;&lt;br /&gt;
&lt;a href=&quot;browse&quot;&gt;Näita turvaümbriku asukohta kettal&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;addFile&quot;&gt;Add file&lt;/a&gt; &lt;a href=&quot;saveAll&quot;&gt;Save files to disk&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;addFile&quot;&gt;Lisa fail&lt;/a&gt; &lt;a href=&quot;saveAll&quot;&gt;Salvesta failid kettale&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;addRecipient&quot;&gt;Add recipient&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;addRecipient&quot;&gt;Lisa adressaat&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%1 already exists.&lt;br /&gt;Do you want replace it?</source>
        <translation>%1 on juba olemas.&lt;br /&gt;Kas sa tahad seda asendada?</translation>
    </message>
    <message>
        <source>Failed to start process &apos;%1&apos;</source>
        <translation>Protsessi &apos;%1&apos; loomine ebaõnnestus</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
&lt;b&gt;File encryption&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;
The purpose of file encryption is to make the data stored in the file unreadable for any unauthorised users.&lt;br /&gt;&lt;br /&gt;
Encryption with ID-card is not meant for long and secure data storage, it is only meant for secure transferring of data over unsecure media.&lt;br /&gt;&lt;br /&gt;
For encryption AS Sertifitseerimiskeskus&apos; LDAP service is used, to search for reciever(s) certificates. Documents are encrypted with public key that is found the certificate.&lt;/p&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Warning&lt;/b&gt;&lt;/font&gt;&lt;br /&gt;&lt;br /&gt;
&lt;b&gt;Encryption is one-way only. Private key needed for decryption is stored only on reciever&apos;s ID-card. Decryption of files is impossible if ID-card is lost or damaged, sertificates are expired or renewed. &lt;/b&gt;
&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
&lt;b&gt;Failide krüpteerimine&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;
Faili krüpteerimise eesmärgiks on muuta selles asuvad andmed võõrastele loetamatuteks.&lt;br /&gt;&lt;br /&gt;
ID-kaardi sertifikaatidega krüptimine ei ole mõeldud andmete pikaajaliseks turvaliseks säilitamiseks ja muude ülesannete lahendamiseks. See on ainult viis failide edastamiseks üle ebaturvalise sideknanali.&lt;br /&gt;&lt;br /&gt;
Failide krüptimisel kasutatakse AS Sertifitseerimiskeskuse LDAP teenust saaja(te) sertifikaatide otsimiseks. Failid krüptitakse sertifikaadis sisalduva avaliku võtmega. Krüptimine on ühesuunaline, dekrüpteerimiseks on vaja vastava sertifikaadi privaatvõtit, mis on salvestatud ainult vastava isiku ID-kaardil.&lt;/p&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;&lt;font color=&quot;red&quot;&gt;&lt;b&gt;HOIATUS:&lt;/b&gt;&lt;/font&gt;&lt;br /&gt;&lt;br /&gt;
&lt;b&gt;Kuna dekrüpteerimist võimaldav sertifikaat on salvestatud ainult ID-kaardile, pole pärast ID-kaardi kaotamist, aegumist, uuendamist, tühistamist või mehaanilist kiibi vigastamist dekrüpteerimine tehniliselt võimalik&lt;/b&gt;
&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Encrypt documents</source>
        <translation>Krüpteerida faile</translation>
    </message>
    <message>
        <source>View encrypted document content</source>
        <translation>Vaadata turvaümbriku sisu</translation>
    </message>
    <message>
        <source>Decrypting</source>
        <translation>Dekrüpteerimine</translation>
    </message>
    <message>
        <source>You dont have permissions to write file %1</source>
        <translation>Sul ei ole piisavalt õigusi et kirjutada faili %1</translation>
    </message>
    <message>
        <source>Documents (*.cdoc *.CDOC)</source>
        <translation>Turvaümbrikud (*.cdoc *.CDOC)</translation>
    </message>
    <message>
        <source>DigiDoc3 Crypto</source>
        <translation>DigiDoc3 Krüpto</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <source>File does not exists %1</source>
        <translation>Valitud faili ei eksisteeri %1</translation>
    </message>
    <message>
        <source>Wrong PIN or PIN is blocked</source>
        <translation>Vale PIN või PIN on lukus</translation>
    </message>
</context>
<context>
    <name>Poller</name>
    <message>
        <source>Authentication certificate is not selected.</source>
        <translation>Audentimise sertifikaat ei ole valitud.</translation>
    </message>
    <message>
        <source>Failed to login token</source>
        <translation>Vale PIN</translation>
    </message>
    <message>
        <source>PIN acquisition canceled.</source>
        <translation>PIN koodi päring katkestati.</translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>Vale PIN</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN on lukus</translation>
    </message>
    <message>
        <source>Failed to decrypt document</source>
        <translation>Dokumenti dekrüpteerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Failed to load PKCS#11 module</source>
        <translation>PKCS#11 mooduli laadimine ebaõnnestus</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Container default location</source>
        <translation>Turvaümbriku loomise vaikekataloog</translation>
    </message>
    <message>
        <source>Select folder</source>
        <translation>Vali kataloog</translation>
    </message>
    <message>
        <source>Show encrypting intro</source>
        <translation>Näita krüpteerimisel sissejuhatust</translation>
    </message>
    <message>
        <source>Same folder</source>
        <translation>Samasse kataloogi</translation>
    </message>
    <message>
        <source>Ask container name</source>
        <translation>Küsi turvaümbriku nime</translation>
    </message>
    <message>
        <source>It is not possible to change the file location. Changes will be valid to new containers only.</source>
        <translation>Juba avatud ümbriku asukohta pole võimalik muuta. See seade kehtib ainult uutele ümbrikutele.</translation>
    </message>
</context>
<context>
    <name>TreeWidget</name>
    <message>
        <source>Save</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Salvesta fail</translation>
    </message>
</context>
</TS>
